@@ -1,22 +1,9 @@
 /*
- * This file is part of the KDE project
- * Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KCAPACITYBAR_H
 #define KCAPACITYBAR_H
@@ -28,6 +15,8 @@
 class QPaintEvent;
 
 /**
+  * @class KCapacityBar kcapacitybar.h KCapacityBar
+  *
   * @brief This widget shows a bar which is filled to show the level of usage of
   *        a certain device.
   *
@@ -37,7 +26,7 @@ class QPaintEvent;
   *
   * @since 4.2
   *
-  * \image html kcapacitybar.png "KDE Capacity Bar"
+  * \image html kcapacitybar.png "KCapacityBar Widget"
   *
   * @author Rafael Fernández López <ereslibre@kde.org>
   */
@@ -68,7 +57,7 @@ public:
      * @param parent The parent of the widget.
      * @since 5.24
      */
-    explicit KCapacityBar(QWidget *parent = Q_NULLPTR);
+    explicit KCapacityBar(QWidget *parent = nullptr);
 
     /**
       * Capacity bar constructor.
@@ -77,8 +66,8 @@ public:
       *                     or not.
       * @param parent       The parent of the widget.
       */
-    explicit KCapacityBar(DrawTextMode drawTextMode, QWidget *parent = 0);
-    ~KCapacityBar();
+    explicit KCapacityBar(DrawTextMode drawTextMode, QWidget *parent = nullptr);
+    ~KCapacityBar() override;
 
     /**
       * Capacity bar fill value.
@@ -198,7 +187,7 @@ public:
     /**
      * Set the way text is drawn if any is set
      *
-     * @param drawTextMode If any text set, whether to draw it into the capacity bar
+     * @param mode If any text set, whether to draw it into the capacity bar
      *                     or not.
      */
     void setDrawTextMode(DrawTextMode mode);
@@ -216,14 +205,14 @@ public:
     void drawCapacityBar(QPainter *p, const QRect &rect) const;
 
     // Reimplemented from QWidget
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    QSize minimumSizeHint() const override;
 
 protected:
     // Reimplemented from QWidget
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
 
     // Reimplemented from QWidget
-    void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *event) override;
 
 private:
     /**
