@@ -1,22 +1,9 @@
 /*
- * This file is part of the KDE libraries
- * Copyright (C) 2006-2007 Sebastian Trueg <trueg@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006-2007 Sebastian Trueg <trueg@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KRATINGWIDGET_H
 #define KRATINGWIDGET_H
@@ -51,12 +38,12 @@ public:
     /**
      * Creates a new rating widget.
      */
-    KRatingWidget(QWidget *parent = nullptr);
+    explicit KRatingWidget(QWidget *parent = nullptr);
 
     /**
      * Destructor
      */
-    ~KRatingWidget();
+    ~KRatingWidget() override;
 
     /**
      * \return The current rating.
@@ -91,7 +78,7 @@ public:
      */
     int spacing() const;
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     /**
      * If half steps are enabled one star equals to 2 rating
@@ -124,11 +111,12 @@ public Q_SLOTS:
      */
     void setRating(int rating);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * \deprecated use setRating( int rating )
+     * \deprecated Since 5.0, use setRating(int rating)
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setRating(unsigned int rating);
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRatingWidget::setRating(int)")
+    void setRating(unsigned int rating);
 #endif
 
     /**
@@ -138,11 +126,12 @@ public Q_SLOTS:
      */
     void setMaxRating(int max);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * \deprecated use setMaxRating( int max )
+     * \deprecated Since 5.0, use setMaxRating( int max )
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setMaxRating(unsigned int max);
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRatingWidget::setMaxRating(int)")
+    void setMaxRating(unsigned int max);
 #endif
 
     /**
@@ -151,11 +140,12 @@ public Q_SLOTS:
      */
     void setHalfStepsEnabled(bool enabled);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * \deprecated Use setHalfStepsEnabled
+     * \deprecated Since 5.0, use setHalfStepsEnabled(bool).
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setOnlyPaintFullSteps(bool);
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRatingWidget::setHalfStepsEnabled(bool)")
+    void setOnlyPaintFullSteps(bool);
 #endif
 
     /**
@@ -184,14 +174,15 @@ public Q_SLOTS:
      */
     void setCustomPixmap(const QPixmap &pixmap);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Set the pixap to be used to display a rating step.
      * By default the "rating" pixmap is loaded.
      *
-     * \deprecated use setCustomPixmap
+     * \deprecated Since 5.0, use setCustomPixmap()
      */
-#ifndef KWIDGETSADDONS_NO_DEPRECATED
-    KWIDGETSADDONS_DEPRECATED void setPixmap(const QPixmap &);
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 0, "Use KRatingWidget::setCustomPixmap(const QPixmap&)")
+    void setPixmap(const QPixmap &);
 #endif
 
     /**
@@ -202,11 +193,11 @@ public Q_SLOTS:
     void setPixmapSize(int size);
 
 protected:
-    void mousePressEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *e) Q_DECL_OVERRIDE;
-    void leaveEvent(QEvent *e) Q_DECL_OVERRIDE;
-    void paintEvent(QPaintEvent *e) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *e) override;
+    void mouseMoveEvent(QMouseEvent *e) override;
+    void leaveEvent(QEvent *e) override;
+    void paintEvent(QPaintEvent *e) override;
+    void resizeEvent(QResizeEvent *e) override;
 
 private:
     class Private;
