@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007-2009 Urs Wolfer <uwolfer @ kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007-2009 Urs Wolfer <uwolfer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB. If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTITLEWIDGET_H
@@ -68,7 +57,14 @@ class KWIDGETSADDONS_EXPORT KTitleWidget : public QWidget
     Q_OBJECT
     Q_PROPERTY(QString text READ text WRITE setText)
     Q_PROPERTY(QString comment READ comment WRITE setComment)
+    /// @since 5.72
+    Q_PROPERTY(QIcon icon READ icon WRITE setIcon)
+    /// @since 5.72
+    Q_PROPERTY(QSize iconSize READ iconSize WRITE setIconSize)
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 72)
+    /// @deprecated Since 5.72, use property icon instead
     Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap)
+#endif
     Q_PROPERTY(int autoHideTimeout READ autoHideTimeout WRITE setAutoHideTimeout)
 
 public:
@@ -118,11 +114,31 @@ public:
      */
     QString comment() const;
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      * @return the pixmap displayed in the title
      * @see setPixmap()
+     * @deprecated Since 5.72, use icon()
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use KTitleWidget::icon()")
     const QPixmap *pixmap() const;
+#endif
+
+    /**
+     * @return the icon displayed in the title
+     * @see setIcon()
+     *
+     * @since 5.72
+     */
+    QIcon icon() const;
+
+    /**
+     * @return the size of the icon displayed in the title
+     * @see setIconSize()
+     *
+     * @since 5.72
+     */
+    QSize iconSize() const;
 
     /**
      * Sets this label's buddy to buddy.
@@ -141,7 +157,7 @@ public:
 
     /**
      * @return The level of this title: it influences the font size following the guidelines at
-     *         https://www.my-scratch.de/HIG/style/typography.html
+     *         https://hig.kde.org/style/typography.html
      *         It also corresponds to the level api of Kirigami Heading for QML applications
      * @since 5.53
      */
@@ -179,12 +195,17 @@ public Q_SLOTS:
      */
     void setIcon(const QIcon &icon, ImageAlignment alignment = ImageRight);
 
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
+     * Sets the icon to the @p pixmap and also the icon size to the size of the @p pixmap.
      * @param pixmap Pixmap displayed in the header. The pixmap is by default right, but
      * @param alignment can be used to display it also left.
      * @see pixmap()
+     * @deprecated Since 5.72, use setIcon(const QIcon &, ImageAlignment)
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use KTitleWidget::setIcon(const QIcon &, ImageAlignment)")
     void setPixmap(const QPixmap &pixmap, ImageAlignment alignment = ImageRight);
+#endif
 
 #if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 63)
     /**
@@ -208,12 +229,34 @@ public Q_SLOTS:
     void setPixmap(const QIcon &icon, ImageAlignment alignment = ImageRight);
 #endif
 
+    /**
+     * @param type the type of message icon to display in the header
+     * @param alignment alignment of the icon (default is right aligned).
+     * @see icon()
+     * @since 5.72
+     */
+    void setIcon(MessageType type, ImageAlignment alignment = ImageRight);
+
+#if KWIDGETSADDONS_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      * @param type the type of message icon to display in the header. The pixmap is by default right, but
      * @param alignment can be used to display it also left.
      * @see pixmap()
+     * @deprecated Since 5.72 use setIcon(MessageType, ImageAlignment) instead
      */
+    KWIDGETSADDONS_DEPRECATED_VERSION(5, 72, "Use KTitleWidget::setIcon(MessageType, ImageAlignment)")
     void setPixmap(MessageType type, ImageAlignment alignment = ImageRight);
+#endif
+
+    /**
+     * Set the size of the icon to display in the header.
+     * @param iconSize the size of the icon, or an invalid QSize to reset to the default
+     *
+     * The default size is defined by the GUI style and its value for QStyle::PM_MessageBoxIconSize.
+     *
+     * @since 5.72
+     */
+    void setIconSize(const QSize &iconSize);
 
     /**
      * Set the autohide timeout of the label
@@ -224,7 +267,7 @@ public Q_SLOTS:
 
     /**
      * Sets the level of this title, similar to HTML's h1 h2 h3...
-     * follows KDE HIG https://www.my-scratch.de/HIG/style/typography.html
+     * follows KDE HIG https://hig.kde.org/style/typography.html
      * @param level the level of the title, 1 is the biggest font and most important, descending
      * @since 5.53
      */
